==> haskell-microstache-1.0.1.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-LiPfeHlyxBP62bEWiTk9nk
key: microstache-1.0.1.1-LiPfeHlyxBP62bEWiTk9nk
license: BSD3
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
abi: 6b590e94102019640ed2d0664353b18e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-LiPfeHlyxBP62bEWiTk9nk
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    directory-1.3.0.0 filepath-1.4.1.1
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microstache-1.0.1.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-microstache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microstache
version: 1.0.1.1
id: microstache-1.0.1.1-79K7XUD403pK7AkzQtM9Hu
key: microstache-1.0.1.1-79K7XUD403pK7AkzQtM9Hu
license: BSD3
maintainer: Oleg Grenrus<oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/microstache
synopsis: Mustache templates for Haskell
description:
    Mustache templates for Haskell.
    .
    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.
category: Text
author: Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type
abi: 4f1494962d0e3ea6d4366d8bf6ee4264
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/microstache-1.0.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/microstache-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/microstache-1.0.1.1
hs-libraries: HSmicrostache-1.0.1.1-79K7XUD403pK7AkzQtM9Hu
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    directory-1.3.0.0 filepath-1.4.1.1
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
haddock-interfaces: /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html: /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
